@@ -1,7 +1,9 @@
 import logging
 
-from django.core.exceptions import PermissionDenied
-from rest_framework.exceptions import ValidationError
+from django.utils.translation import gettext_lazy as _
+
+from rest_framework.exceptions import PermissionDenied, ValidationError
+
 
 logger = logging.getLogger(__name__)
 
@@ -10,6 +12,7 @@ class LoggedPermissionDenied(PermissionDenied):
 
     def __init__(self, *args, **kwargs):
         logger.warning(f'API {kwargs.get("classname")} {kwargs.get("resource")} permission denied')
+        super().__init__(detail=kwargs.get('detail', _('You do not have permission to perform this action.')))
 
 
 class LoggedValidationException(ValidationError):
