@@ -1,3 +1,4 @@
+import datetime
 import logging
 
 from django.core.exceptions import ObjectDoesNotExist
@@ -48,6 +49,7 @@ class WebpathAPIUnitTest(TestCase):
         req = Client()
         ebu = ContextUnitTest.create_editorialboard_user()
         webpath = ebu.webpath
+
         url = reverse('unicms_api:editorial-board-site-webpath',
                       kwargs={'site_id': webpath.site.pk,
                               'pk': webpath.pk})
@@ -77,6 +79,13 @@ class WebpathAPIUnitTest(TestCase):
         res = req.get(url)
         assert isinstance(res.json(), list)
 
+        # GET LOGS
+        url = reverse('unicms_api:editorial-board-site-webpath-logs',
+                      kwargs={'site_id': webpath.site.pk,
+                              'pk': webpath.pk})
+        res = req.get(url, content_type='application/json',)
+        assert isinstance(res.json(), dict)
+
     def test_patch(self):
         req = Client()
         ebu_parent = ContextUnitTest.create_editorialboard_user()
@@ -227,7 +236,7 @@ class WebpathAPIUnitTest(TestCase):
 
         # edit child parent
         ebu_child = ContextUnitTest.create_editorialboard_user(user=user,
-                                                               webpath=ContextUnitTest.create_webpath(),
+                                                               webpath=ContextUnitTest.create_webpath(path=datetime.datetime.now().strftime("%f")),
                                                                permission=3,
                                                                is_active=True)
         child = ebu_child.webpath
@@ -238,7 +247,8 @@ class WebpathAPIUnitTest(TestCase):
                                     'pk': child.pk})
 
         # change parent
-        new_parent = ContextUnitTest.create_webpath(site=site)
+        new_parent = ContextUnitTest.create_webpath(site=site,
+                                                    path=datetime.datetime.now().strftime("%f"))
         child_json = {'site': site.pk,
                       'parent': new_parent.pk,
                       'name': 'child name',
