@@ -1,5 +1,6 @@
 import logging
 
+from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ValidationError
 from django.http import Http404
 from django.shortcuts import get_object_or_404
@@ -21,6 +22,7 @@ from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.views import APIView
 
 from . generics import UniCMSCachedRetrieveUpdateDestroyAPIView, UniCMSListCreateAPIView, UniCMSListSelectOptionsAPIView, check_locks
+from . logs import ObjectLogEntriesList
 from .. exceptions import LoggedPermissionDenied
 from .. permissions import PublicationGetCreatePermissions
 from .. serializers import UniCMSFormSerializer
@@ -243,17 +245,17 @@ class PublicationRelatedObject(UniCMSCachedRetrieveUpdateDestroyAPIView):
     def patch(self, request, *args, **kwargs):
         item = self.get_queryset().first()
         if not item: raise Http404
-        serializer = self.get_serializer(instance=item,
-                                         data=request.data,
-                                         partial=True)
-        if serializer.is_valid(raise_exception=True):
-            publication = item.publication
-            # check permissions on publication
-            has_permission = publication.is_editable_by(request.user)
-            if not has_permission:
-                raise LoggedPermissionDenied(classname=self.__class__.__name__,
-                                             resource=request.method)
-            return super().patch(request, *args, **kwargs)
+        # serializer = self.get_serializer(instance=item,
+        # data=request.data,
+        # partial=True)
+        # if serializer.is_valid(raise_exception=True):
+        publication = item.publication
+        # check permissions on publication
+        has_permission = publication.is_editable_by(request.user)
+        if not has_permission:
+            raise LoggedPermissionDenied(classname=self.__class__.__name__,
+                                         resource=request.method)
+        return super().patch(request, *args, **kwargs)
 
     def put(self, request, *args, **kwargs):
         item = self.get_queryset().first()
@@ -317,3 +319,32 @@ class PublicationOptionView(generics.RetrieveAPIView):
         pub_id = self.kwargs['pk']
         publications = Publication.objects.filter(pk=pub_id)
         return publications
+
+
+class PublicationLogsSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listPublicationLogs'
+
+
+class PublicationLogsView(ObjectLogEntriesList):
+
+    schema = PublicationLogsSchema()
+
+    def get_queryset(self, **kwargs):
+        """
+        """
+        object_id = self.kwargs['pk']
+        item = Publication.objects.filter(pk=object_id).first()
+        content_type_id = ContentType.objects.get_for_model(item).pk
+        return super().get_queryset(object_id, content_type_id)
+
+
+class PublicationRelatedObjectLogsView(ObjectLogEntriesList):
+
+    def get_data(self):
+        pub_id = self.kwargs['publication_id']
+        self.pk = self.kwargs['pk']
+        self.publication = get_object_or_404(Publication, pk=pub_id)
+
+    def get_queryset(self, object_id, content_type_id):
+        return super().get_queryset(object_id, content_type_id)
