@@ -70,7 +70,7 @@ class WebPath(ActivableModel, TimeStampedModel, CreatedModifiedBy):
                                            'the parent one, on save'))
     alias = models.ForeignKey('WebPath',
                               null=True, blank=True,
-                              on_delete=models.CASCADE,
+                              on_delete=models.SET_NULL,
                               related_name="alias_path",
                               help_text=_('Alias that would be '
                                           'redirected to ...'))
@@ -113,6 +113,22 @@ class WebPath(ActivableModel, TimeStampedModel, CreatedModifiedBy):
         url = f'/{CMS_PATH_PREFIX}{self.fullpath}'
         return sanitize_path(url)
 
+    def get_site_path(self, request=None):
+        """
+        returns webpath full path with site domain
+        """
+        if self.is_alias:
+            return self.redirect_url
+        # ports to exclude
+        excluded_ports = ["80", "443"]
+        if request and request.META['SERVER_PORT'] not in excluded_ports:
+            domain = f'{self.site.domain}:{request.META["SERVER_PORT"]}'
+        else:
+            domain = f'{self.site.domain}'
+        path = sanitize_path(f'{CMS_PATH_PREFIX}{self.fullpath}')
+        url = f'//{domain}/{path}'
+        return url
+
     def save(self, *args, **kwargs):
         # manage aliases
         if self.alias:
