@@ -1,4 +1,6 @@
 from django.conf import settings
+from django.contrib.admin.models import LogEntry
+from django.utils.text import slugify
 
 from cms.api.serializers import UniCMSCreateUpdateSerializer, UniCMSContentTypeClass
 
@@ -83,6 +85,24 @@ class WebPathSerializer(UniCMSCreateUpdateSerializer, UniCMSContentTypeClass):
             data['permission_label'] = context_permissions[permission]
         return data
 
+    def validate_path(self, value):
+        """
+        slugify path
+        """
+        return slugify(value)
+
+    # def create(self, validated_data):
+        # try:
+            # return WebPath.objects.create(**validated_data)
+        # except Exception as e:
+            # raise e
+
+    # def update(self, instance, validated_data):
+        # try:
+            # return super().update(instance, validated_data)
+        # except Exception as e:
+            # raise e
+
 
 class WebPathSelectOptionsSerializer(serializers.ModelSerializer):
 
@@ -95,3 +115,15 @@ class WebPathSelectOptionsSerializer(serializers.ModelSerializer):
     class Meta:
         model = WebPath
         fields = ()
+
+
+class LogEntrySerializer(serializers.ModelSerializer):
+
+    def to_representation(self, instance):
+        data = super().to_representation(instance)
+        data['user'] = instance.user.__str__()
+        return data
+
+    class Meta:
+        model = LogEntry
+        fields = '__all__'
