@@ -5,9 +5,9 @@ from django.db import models
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 
-from cms.contexts.models import CreatedModifiedBy
 from cms.contexts.models_abstract import AbstractLockable
 from cms.templates.models import (ActivableModel,
+                                  CreatedModifiedBy,
                                   SortableModel,
                                   TimeStampedModel)
 
@@ -66,7 +66,7 @@ class MediaCollection(ActivableModel, TimeStampedModel,
         return self.name
 
 
-class Media(ActivableModel, TimeStampedModel, AbstractMedia,
+class Media(TimeStampedModel, AbstractMedia,
             AbstractLockable, CreatedModifiedBy):
     title = models.CharField(max_length=60, blank=False, null=False,
                              help_text=_("Media file title"))
@@ -89,15 +89,13 @@ class Media(ActivableModel, TimeStampedModel, AbstractMedia,
 
 class MediaCollectionItem(ActivableModel, SortableModel,
                           TimeStampedModel, CreatedModifiedBy):
-    media = models.ForeignKey(Media, on_delete=models.CASCADE,
-                              limit_choices_to={'is_active': True},)
+    media = models.ForeignKey(Media, on_delete=models.PROTECT)
     collection = models.ForeignKey(MediaCollection,
-                                   on_delete=models.CASCADE,
-                                   limit_choices_to={'is_active': True},)
+                                   on_delete=models.CASCADE)
 
     class Meta:
         ordering = ['order']
         verbose_name_plural = _("Media Collection Items")
 
     def __str__(self): # pragma: no cover
-        return '{} {}'.format(self.collection, self.media)
+        return '[{}] {}'.format(self.collection, self.media)
