@@ -109,7 +109,7 @@ class PublicationAttachmentSerializer(UniCMSCreateUpdateSerializer,
     class Meta:
         model = PublicationAttachment
         fields = '__all__'
-        read_only_fields = ('file_size','file_type')
+        read_only_fields = ('created_by', 'modified_by', 'file_size','file_type')
 
 
 class PublicationBlockSerializer(UniCMSCreateUpdateSerializer,
@@ -152,7 +152,6 @@ class PublicationLocalizationSerializer(UniCMSCreateUpdateSerializer,
     class Meta:
         model = PublicationLocalization
         fields = '__all__'
-        read_only_fields = ('created_by', 'modified_by')
 
 
 class PublicationRelatedSerializer(UniCMSCreateUpdateSerializer,
